arelle Package
==============

:mod:`Cntlr` Module
-------------------

.. automodule:: arelle.Cntlr
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`CntlrCmdLine` Module
--------------------------

.. automodule:: arelle.CntlrCmdLine
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`CntlrComServer` Module
----------------------------

.. automodule:: arelle.CntlrComServer
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`CntlrGenVersReports` Module
---------------------------------

.. automodule:: arelle.CntlrGenVersReports
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`CntlrProfiler` Module
---------------------------

.. automodule:: arelle.CntlrProfiler
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`CntlrWebMain` Module
--------------------------

.. automodule:: arelle.CntlrWebMain
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`DisclosureSystem` Module
------------------------------

.. automodule:: arelle.DisclosureSystem
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FileSource` Module
------------------------

.. automodule:: arelle.FileSource
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FormulaConsisAsser` Module
--------------------------------

.. automodule:: arelle.FormulaConsisAsser
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FormulaEvaluator` Module
------------------------------

.. automodule:: arelle.FormulaEvaluator
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FunctionCustom` Module
----------------------------

.. automodule:: arelle.FunctionCustom
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FunctionFn` Module
------------------------

.. automodule:: arelle.FunctionFn
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FunctionIxt` Module
-------------------------

.. automodule:: arelle.FunctionIxt
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FunctionUtil` Module
--------------------------

.. automodule:: arelle.FunctionUtil
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FunctionXfi` Module
-------------------------

.. automodule:: arelle.FunctionXfi
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`FunctionXs` Module
------------------------

.. automodule:: arelle.FunctionXs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`HtmlUtil` Module
----------------------

.. automodule:: arelle.HtmlUtil
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`InstanceAspectsEvaluator` Module
--------------------------------------

.. automodule:: arelle.InstanceAspectsEvaluator
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Locale` Module
--------------------

.. automodule:: arelle.Locale
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelDocument` Module
---------------------------

.. automodule:: arelle.ModelDocument
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelDtsObject` Module
----------------------------

.. automodule:: arelle.ModelDtsObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelFormulaObject` Module
--------------------------------

.. automodule:: arelle.ModelFormulaObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelInstanceObject` Module
---------------------------------

.. automodule:: arelle.ModelInstanceObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelManager` Module
--------------------------

.. automodule:: arelle.ModelManager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelObject` Module
-------------------------

.. automodule:: arelle.ModelObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelObjectFactory` Module
--------------------------------

.. automodule:: arelle.ModelObjectFactory
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelRelationshipSet` Module
----------------------------------

.. automodule:: arelle.ModelRelationshipSet
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelRenderingObject` Module
----------------------------------

.. automodule:: arelle.ModelRenderingObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelRssItem` Module
--------------------------

.. automodule:: arelle.ModelRssItem
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelRssObject` Module
----------------------------

.. automodule:: arelle.ModelRssObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelTestcaseObject` Module
---------------------------------

.. automodule:: arelle.ModelTestcaseObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelValue` Module
------------------------

.. automodule:: arelle.ModelValue
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelVersObject` Module
-----------------------------

.. automodule:: arelle.ModelVersObject
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelVersReport` Module
-----------------------------

.. automodule:: arelle.ModelVersReport
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ModelXbrl` Module
-----------------------

.. automodule:: arelle.ModelXbrl
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Updater` Module
---------------------

.. automodule:: arelle.Updater
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`UrlUtil` Module
---------------------

.. automodule:: arelle.UrlUtil
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Validate` Module
----------------------

.. automodule:: arelle.Validate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateFiling` Module
----------------------------

.. automodule:: arelle.ValidateFiling
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateFilingDTS` Module
-------------------------------

.. automodule:: arelle.ValidateFilingDTS
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateFilingDimensions` Module
--------------------------------------

.. automodule:: arelle.ValidateFilingDimensions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateFilingText` Module
--------------------------------

.. automodule:: arelle.ValidateFilingText
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateFormula` Module
-----------------------------

.. automodule:: arelle.ValidateFormula
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateHmrc` Module
--------------------------

.. automodule:: arelle.ValidateHmrc
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateUtr` Module
-------------------------

.. automodule:: arelle.ValidateUtr
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateVersReport` Module
--------------------------------

.. automodule:: arelle.ValidateVersReport
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateXbrl` Module
--------------------------

.. automodule:: arelle.ValidateXbrl
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateXbrlCalcs` Module
-------------------------------

.. automodule:: arelle.ValidateXbrlCalcs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateXbrlDTS` Module
-----------------------------

.. automodule:: arelle.ValidateXbrlDTS
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ValidateXbrlDimensions` Module
------------------------------------

.. automodule:: arelle.ValidateXbrlDimensions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Version` Module
---------------------

.. automodule:: arelle.Version
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFile` Module
----------------------

.. automodule:: arelle.ViewFile
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileConcepts` Module
------------------------------

.. automodule:: arelle.ViewFileConcepts
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileDTS` Module
-------------------------

.. automodule:: arelle.ViewFileDTS
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileFactList` Module
------------------------------

.. automodule:: arelle.ViewFileFactList
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileFactTable` Module
-------------------------------

.. automodule:: arelle.ViewFileFactTable
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileFormulae` Module
------------------------------

.. automodule:: arelle.ViewFileFormulae
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileRelationshipSet` Module
-------------------------------------

.. automodule:: arelle.ViewFileRelationshipSet
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileRenderedGrid` Module
----------------------------------

.. automodule:: arelle.ViewFileRenderedGrid
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewFileTests` Module
---------------------------

.. automodule:: arelle.ViewFileTests
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewUtil` Module
----------------------

.. automodule:: arelle.ViewUtil
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewUtilFormulae` Module
------------------------------

.. automodule:: arelle.ViewUtilFormulae
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ViewUtilRenderedGrid` Module
----------------------------------

.. automodule:: arelle.ViewUtilRenderedGrid
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`WebCache` Module
----------------------

.. automodule:: arelle.WebCache
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XPathContext` Module
--------------------------

.. automodule:: arelle.XPathContext
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XPathParser` Module
-------------------------

.. automodule:: arelle.XPathParser
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XbrlConst` Module
-----------------------

.. automodule:: arelle.XbrlConst
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XbrlUtil` Module
----------------------

.. automodule:: arelle.XbrlUtil
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XmlUtil` Module
---------------------

.. automodule:: arelle.XmlUtil
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XmlValidate` Module
-------------------------

.. automodule:: arelle.XmlValidate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`XmlValidateParticles` Module
----------------------------------

.. automodule:: arelle.XmlValidateParticles
    :members:
    :undoc-members:
    :show-inheritance:



